"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var InputNodeChangeType;
(function (InputNodeChangeType) {
    InputNodeChangeType[InputNodeChangeType["None"] = 0] = "None";
    InputNodeChangeType[InputNodeChangeType["Deadband"] = 1] = "Deadband";
    InputNodeChangeType[InputNodeChangeType["RisingEdgeOnly"] = 2] = "RisingEdgeOnly";
    InputNodeChangeType[InputNodeChangeType["FallingEdgeOnly"] = 3] = "FallingEdgeOnly";
})(InputNodeChangeType = exports.InputNodeChangeType || (exports.InputNodeChangeType = {}));
class InputNodeScanner {
    constructor(scanTimeMs, nodeChangeType, deadband, sendInitialValue, scanCallback) {
        this.initialValueSent = false;
        this.deadband = deadband;
        this.scanTimeMs = scanTimeMs;
        this.nodeChangeType = nodeChangeType;
        this.sendInitialValue = sendInitialValue;
        this.scanCallback = scanCallback;
    }
    close() {
        if (this.timer) {
            clearTimeout(this.timer);
        }
        this.doScan = false;
    }
    startScan() {
        this.doScan = true;
        this.timer = setTimeout(this.scanCallback, this.scanTimeMs);
    }
    updateValue(newValue) {
        var valueChanged = false;
        var sendInitialValue = !this.initialValueSent && this.sendInitialValue;
        this.initialValueSent = true;
        if (this.lastValue === undefined) {
            this.lastValue = newValue;
        }
        if (this.nodeChangeType == InputNodeChangeType.Deadband) {
            if (sendInitialValue) {
                valueChanged = true;
            }
            else {
                if ((newValue >= (this.lastValue + this.deadband)) ||
                    (newValue <= (this.lastValue - this.deadband))) {
                    valueChanged = true;
                }
            }
        }
        else if (this.nodeChangeType == InputNodeChangeType.RisingEdgeOnly) {
            if (sendInitialValue && newValue) {
                valueChanged = true;
            }
            else {
                valueChanged = newValue && !this.lastValue;
            }
            this.lastValue = newValue;
        }
        else if (this.nodeChangeType == InputNodeChangeType.FallingEdgeOnly) {
            if (sendInitialValue && !newValue) {
                valueChanged = true;
            }
            else {
                valueChanged = !newValue && this.lastValue;
            }
            this.lastValue = newValue;
        }
        else {
            if (sendInitialValue) {
                valueChanged = true;
            }
            else {
                valueChanged = this.lastValue != newValue;
            }
        }
        if (valueChanged) {
            this.lastValue = newValue;
        }
        if (this.doScan) {
            this.timer = setTimeout(this.scanCallback, this.scanTimeMs);
        }
        return valueChanged;
    }
    updateError() {
        if (this.doScan) {
            this.timer = setTimeout(this.scanCallback, this.scanTimeMs);
        }
    }
}
exports.InputNodeScanner = InputNodeScanner;
