"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ConfigHandler = require("./config-node");
class NodeBaseImpl {
    constructor(nodeConfig, deviceConfig, node) {
        this.nodeConfig = nodeConfig;
        this.deviceConfig = deviceConfig;
        this.node = node;
        if (deviceConfig) {
            this.deviceConnection = ConfigHandler.globalConnections.getConnection(deviceConfig.id);
            this.apiClient = this.deviceConnection.apiClient;
        }
        else {
            this.node.error('Missing device configuration', '');
        }
        this.moduleIndex = parseInt(nodeConfig.moduleIndex);
        this.channelIndex = parseInt(nodeConfig.channelIndex);
        this.mmpLength = parseInt(nodeConfig.mmpLength);
        if (isNaN(this.moduleIndex))
            this.moduleIndex = 0;
        if (isNaN(this.channelIndex))
            this.channelIndex = 0;
        if (isNaN(this.mmpLength))
            this.mmpLength = 1;
    }
}
exports.NodeBaseImpl = NodeBaseImpl;
class FunctionNodeBaseImpl extends NodeBaseImpl {
    constructor(nodeConfig, deviceConfig, node) {
        super(nodeConfig, deviceConfig, node);
        if (deviceConfig) {
            this.msgQueue = this.deviceConnection.queue;
        }
    }
    addMsg(msg) {
        if (!this.apiClient || !this.msgQueue) {
            this.node.status({ fill: "red", shape: "dot", text: 'missing Groov configuration' });
            return;
        }
        var queueLength = this.msgQueue.add(msg, this.node, this, this.onInput);
        var currentMsgBeingProcessed = this.msgQueue.getCurrentMessage();
        if (currentMsgBeingProcessed.inputEventObject !== this) {
            if (queueLength !== 0) {
                this.updateQueuedStatus(queueLength);
            }
        }
    }
    updateQueuedStatus(queueLength) {
        if (queueLength != 0) {
            if (this.previousResponseError) {
                this.node.status({
                    fill: "red", shape: "ring", text: "queued [" +
                        this.previousResponseError.nodeShortErrorMsg + "]"
                });
            }
            else {
                this.node.status({ fill: "green", shape: "ring", text: 'queued' });
            }
        }
    }
}
exports.FunctionNodeBaseImpl = FunctionNodeBaseImpl;
