"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MessageQueue = require("opto22-node-red-common/lib/MessageQueue");
const CertificateUtil = require("opto22-node-red-common/lib/CertificateUtil");
const api_1 = require("../swagger/lib/api");
var RED;
function setRED(globalRED) {
    RED = globalRED;
}
exports.setRED = setRED;
exports.GroovIoDeviceNodeType = 'groov-io-device';
function createDeviceNode(config) {
    RED.nodes.createNode(this, config);
    var address = config.address.trim().toLowerCase();
    var isLocalhost = address === 'localhost';
    var msgQueueFullBehavior = config.msgQueueFullBehavior || 'REJECT_NEW';
    var apiKey = this.credentials.apiKey;
    var publicCertPath = this.credentials.publicCertPath;
    var caCertPath = this.credentials.caCertPath;
    apiKey = apiKey ? apiKey : '';
    publicCertPath = publicCertPath ? publicCertPath.trim() : '';
    caCertPath = caCertPath ? caCertPath.trim() : '';
    var publicCertFile;
    var caCertFile;
    if (apiKey === '') {
        RED.log.error('Missing API key for ' + address);
    }
    if (!isLocalhost) {
        try {
            publicCertFile = CertificateUtil.getCertFile(RED, publicCertPath);
            caCertFile = CertificateUtil.getCertFile(RED, caCertPath);
        }
        catch (err) {
            if (err.code === 'ENOENT') {
                RED.log.error('Cannot open certifcate file at \'' + err.path + '\'.');
            }
            else if (err.code === 'EACCES') {
                RED.log.error('Cannot open certifcate file at \'' + err.path + '\' due to file permissions.');
            }
            else {
                RED.log.error(err);
            }
        }
    }
    var ctrl = exports.globalConnections.createConnection(address, apiKey, publicCertFile, caCertFile, msgQueueFullBehavior, config.id);
    this.on('close', () => {
        ctrl.queue.dump();
    });
}
exports.createDeviceNode = createDeviceNode;
class GroovManageConnection {
    constructor(apiClient, queue) {
        this.apiClient = apiClient;
        this.queue = queue;
    }
}
exports.GroovManageConnection = GroovManageConnection;
class GroovManageConnections {
    constructor() {
        this.connectionCache = [];
    }
    createConnection(address, apiKey, publicCertFile, caCertFile, msgQueueFullBehavior, id) {
        var apiClient = new api_1.DefaultApi(address, apiKey, publicCertFile, caCertFile);
        this.connectionCache[id] = new GroovManageConnection(apiClient, new MessageQueue.default(50, msgQueueFullBehavior));
        return this.connectionCache[id];
    }
    getConnection(id) {
        return this.connectionCache[id];
    }
}
exports.GroovManageConnections = GroovManageConnections;
exports.globalConnections = new GroovManageConnections();
