"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class ErrorDetails {
    constructor(nodeShortErrorMsg, logLongErrorMsg) {
        this.nodeShortErrorMsg = nodeShortErrorMsg;
        this.logLongErrorMsg = logLongErrorMsg;
    }
}
exports.ErrorDetails = ErrorDetails;
class ResponseErrorMessages {
    static getErrorMsg(error) {
        var shortError = 'Error';
        var longError = 'Error';
        if (error.code !== undefined) {
            shortError = ResponseErrorMessages.errors[error.code];
            if (shortError === undefined) {
                shortError = error.code;
                longError = 'Error code: ' + error.code;
            }
            else {
                if (error.code == 'DEPTH_ZERO_SELF_SIGNED_CERT') {
                    longError = 'There is a problem with the SSL public certificate for the target device. ' +
                        'It may not be installed in this device or it may not match the private key in the target device. Error code: ' +
                        error.code;
                }
                else if (error.code == 'ERR_TLS_CERT_ALTNAME_INVALID') {
                    longError = 'The device address does not exactly match the address in the installed SSL certicate. Error code: ' +
                        error.code;
                }
                else {
                    longError = shortError + '. Error code: ' + error.code;
                }
            }
            if (error.syscall !== undefined) {
                longError = longError + ' from system call "' + error.syscall + '"';
            }
        }
        else if (error.reason !== undefined) {
            shortError = error.reason;
            longError = 'Error: ' + error.reason;
        }
        return new ErrorDetails(shortError, longError);
    }
}
ResponseErrorMessages.errors = {
    'ECONNREFUSED': 'Connection refused',
    'ESOCKETTIMEDOUT': 'Timeout',
    'ETIMEDOUT': 'Timeout',
    'EHOSTUNREACH': 'Device unreachable',
    'ENETUNREACH': 'Network unreachable',
    'ENOTFOUND': 'Address not found',
    'EINVAL': 'Invalid argument',
    'EAI_AGAIN': 'Address not found',
    'DEPTH_ZERO_SELF_SIGNED_CERT': 'Security certificate problem',
    'ERR_TLS_CERT_ALTNAME_INVALID': "Address does not match certificate"
};
exports.ResponseErrorMessages = ResponseErrorMessages;
class StatusCodeMessages {
    static getErrorMsg(statusCode) {
        var shortError = StatusCodeMessages.errors[statusCode];
        if (shortError === undefined) {
            shortError = 'Status code ' + statusCode;
        }
        var longError = shortError + '. HTTP response error : ' + statusCode;
        return new ErrorDetails(shortError, longError);
    }
}
StatusCodeMessages.errors = {
    '400': 'Bad request',
    '401': 'Bad API key',
    '404': 'Not found',
    '500': 'Bad API key or server error'
};
exports.StatusCodeMessages = StatusCodeMessages;
function handleErrorResponse(error, msg, node, previousError) {
    var errorDetails;
    if (error !== undefined) {
        if (typeof error === 'string') {
            errorDetails = new ErrorDetails(error, error);
            msg.groovError = {
                message: error
            };
        }
        else if (error.response !== undefined) {
            errorDetails = StatusCodeMessages.getErrorMsg(error.response.statusCode);
            msg.resError = {
                statusCode: error.response.statusCode,
                body: error.response.body
            };
        }
        else {
            errorDetails = ResponseErrorMessages.getErrorMsg(error);
            msg.reqError = error;
        }
    }
    if (errorDetails) {
        node.status({ fill: "red", shape: "dot", text: errorDetails.nodeShortErrorMsg });
        if (previousError && (previousError.logLongErrorMsg == errorDetails.logLongErrorMsg)) {
        }
        else {
            node.error(errorDetails.logLongErrorMsg, msg);
        }
    }
    return errorDetails;
}
exports.handleErrorResponse = handleErrorResponse;
